@@ -4,8 +4,13 @@ use modeling::render::PlantUmlRender;
 
 fn main() {
     let args: Vec<String> = env::args().collect();
+    let mut path = ".".to_string();
+    if args.len() > 1 {
+        path = args[1].clone();
+    }
 
-    let classes = by_dir(".");
+    println!("Input path: {:?}", path.clone());
+    let classes = by_dir(path.as_str());
     let uml = PlantUmlRender::render(&classes);
 
     let _ = fs::write("modeling.puml", uml);
